@@ -29,14 +29,26 @@ test_that("brm_marginal_draws() on response, no subgroup", {
       )
     )
   )
-  old_sep <- emmeans::get_emm_option("sep")
   out <- brm_marginal_draws(
     model = model,
+    formula = formula,
     data = data
   )
+  formula_exclude <- formula
+  attr(formula_exclude, "brm_allow_effect_size") <- FALSE
+  expect_warning(
+    excluded <- brm_marginal_draws(
+      model = model,
+      formula = formula_exclude,
+      data = data
+    ),
+    class = "brm_warn"
+  )
+  expect_false("effect" %in% names(excluded))
   expect_warning(
     brm_marginal_draws(
       model = model,
+      formula = formula,
       data = data,
       control = "group_1"
     ),
@@ -45,12 +57,12 @@ test_that("brm_marginal_draws() on response, no subgroup", {
   expect_warning(
     brm_marginal_draws(
       model = model,
+      formula = formula,
       data = data,
       baseline = "time_1"
     ),
     class = "brm_deprecate"
   )
-  expect_equal(emmeans::get_emm_option("sep"), old_sep)
   fields <- c("response", "difference_time", "difference_group", "effect")
   columns_df <- expand.grid(
     group = sort(unique(data$group)),
@@ -141,13 +153,20 @@ test_that("brm_marginal_draws() on response, with subgroup", {
       )
     )
   )
-  old_sep <- emmeans::get_emm_option("sep")
+  expect_warning(
+    brm_marginal_draws(
+      model = model,
+      formula = formula,
+      data = data,
+      use_subgroup = TRUE
+    ),
+    class = "brm_deprecate"
+  )
   out <- brm_marginal_draws(
     model = model,
-    data = data,
-    use_subgroup = TRUE
+    formula = formula,
+    data = data
   )
-  expect_equal(emmeans::get_emm_option("sep"), old_sep)
   fields <- c(
     "response",
     "difference_time",
@@ -259,7 +278,7 @@ test_that("brm_marginal_draws() on response, with subgroup", {
   }
 })
 
-test_that("brm_marginal_draws() on change, no subgroup", {
+test_that("brm_marginal_draws() on change, homogeneous var, no subgroup", {
   skip_on_cran()
   set.seed(0L)
   data <- brm_data(
@@ -274,7 +293,8 @@ test_that("brm_marginal_draws() on change, no subgroup", {
   formula <- brm_formula(
     data = data,
     baseline = FALSE,
-    baseline_time = FALSE
+    baseline_time = FALSE,
+    sigma = brm_formula_sigma(data = data, intercept = TRUE, time = FALSE)
   )
   tmp <- utils::capture.output(
     suppressMessages(
@@ -291,7 +311,13 @@ test_that("brm_marginal_draws() on change, no subgroup", {
   )
   out <- brm_marginal_draws(
     model = model,
-    data = data
+    formula = formula,
+    data = data,
+    transform = brm_transform_marginal(
+      data = data,
+      formula = formula,
+      average_within_subgroup = FALSE
+    )
   )
   fields <- c("response", "difference_group", "effect")
   columns_df <- expand.grid(
@@ -318,6 +344,11 @@ test_that("brm_marginal_draws() on change, no subgroup", {
     sort(colnames(out$difference_group)),
     sort(c(columns, names_mcmc))
   )
+  draws <- tibble::as_tibble(posterior::as_draws_df(model))
+  draws <- draws[, grep("^b_sigma_", colnames(draws), value = TRUE)]
+  colnames(draws) <- gsub("^b_sigma_", "", colnames(draws))
+  colnames(draws) <- gsub(paste0("^time"), "", x = colnames(draws))
+  sigma <- exp(draws)
   for (group in setdiff(unique(data$group), "group_1")) {
     for (time in unique(data$time)) {
       name1 <- paste("group_1", time, sep = brm_sep())
@@ -326,11 +357,15 @@ test_that("brm_marginal_draws() on change, no subgroup", {
         out$difference_group[[name2]],
         out$response[[name2]] - out$response[[name1]]
       )
+      expect_equal(
+        out$effect[[name2]],
+        out$difference_group[[name2]] / sigma[[1L]]
+      )
     }
   }
 })
 
-test_that("brm_marginal_draws() on change, with subgroup", {
+test_that("brm_marginal_draws() on change, homogeneous var, with subgroup", {
   skip_on_cran()
   set.seed(0L)
   data <- brm_simulate_outline(
@@ -345,7 +380,10 @@ test_that("brm_marginal_draws() on change, with subgroup", {
     name_change = "change",
     name_baseline = "baseline"
   )
-  formula <- brm_formula(data = data)
+  formula <- brm_formula(
+    data = data,
+    sigma = brm_formula_sigma(data = data, intercept = TRUE, time = FALSE)
+  )
   tmp <- utils::capture.output(
     suppressMessages(
       suppressWarnings(
@@ -361,7 +399,13 @@ test_that("brm_marginal_draws() on change, with subgroup", {
   )
   out <- brm_marginal_draws(
     model = model,
-    data = data
+    formula = formula,
+    data = data,
+    transform = brm_transform_marginal(
+      data = data,
+      formula = formula,
+      average_within_subgroup = FALSE
+    )
   )
   fields <- c("response", "difference_group", "difference_subgroup", "effect")
   expect_equal(sort(names(out)), sort(fields))
@@ -422,6 +466,11 @@ test_that("brm_marginal_draws() on change, with subgroup", {
       }
     }
   }
+  draws <- tibble::as_tibble(posterior::as_draws_df(model))
+  draws <- draws[, grep("^b_sigma_", colnames(draws), value = TRUE)]
+  colnames(draws) <- gsub("^b_sigma_", "", colnames(draws))
+  colnames(draws) <- gsub(paste0("^time"), "", x = colnames(draws))
+  sigma <- exp(draws)
   for (group in setdiff(unique(data$group), "group_1")) {
     for (subgroup in setdiff(unique(data$subgroup), "subgroup_1")) {
       for (time in unique(data$time)) {
@@ -431,6 +480,10 @@ test_that("brm_marginal_draws() on change, with subgroup", {
           out$difference_subgroup[[name2]],
           out$difference_group[[name2]] - out$difference_group[[name1]]
         )
+        expect_equal(
+          out$effect[[name2]],
+          out$difference_group[[name2]] / sigma[[1L]]
+        )
       }
     }
   }
